<?php
/**
 * A class holding general data about the application and some methods for
 * the management including the entry point.
 *
 * E.g.:
 *
 * index.php?app=my_app
 *
 * You need to create a folder in the folder "application" named "my_app"
 * (without the quotes) and create a include file called
 * class_ApplicationHelper.php. You have to write the same class for your
 * application and implement the same interface called ManageableApplication
 * because this class include file will be searched for.
 *
 * It is good when you avoid more GET parameters to keep URLs short and sweet.
 * But sometimes you need some GET paramerers e.g. for your imprint or info page
 * or other linked pages which you have to create and state some informations.
 *
 * Please remember that this include file is being loaded *before* the class
 * loader is loading classes from "exceptions", "interfaces" and "main"!
 *
 * @author     Roland Haeder <roland __NOSPAM__ [at] __REMOVE_ME__ mxchange [dot] org>
 * @version    0.1
 */
class ApplicationHelper extends BaseFrameworkSystem implements ManageableApplication {
	/**
	 * The version number of this application
	 */
	private $appVersion = "";

	/**
	 * The human-readable name for this application
	 */
	private $appName = "";

	/**
	 * The short uni*-like name of this application
	 */
	private $shortName = "";

	/**
	 * An instance of this class
	 */
	private static $thisInstance = null;

	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Set description
		$this->setPartDescr("Application-Helper");

		// Create an unique ID
		$this->createUniqueID();

		// Tidy up a little
		$this->removeSystemArray();
	}

	/**
	 * Getter for an instance of this class
	 *
	 * @return	$thisInstance		An instance of this class
	 */
	public final static function getInstance () {
		// Is the instance there?
		if (is_null(self::$thisInstance)) {
			self::$thisInstance = new ApplicationHelper();
		}

		// Return the instance
		return self::$thisInstance;
	}

	/**
	 * Getter for the version number
	 *
	 * @return	$appVersion	The application's version number
	 */
	public final function getAppVersion () {
		return $this->appVersion;
	}

	/**
	 * Setter for the version number
	 *
	 * @param		$appVersion	The application's version number
	 * @return	void
	 */
	public final function setAppVersion ($appVersion) {
		// Cast and set it
		$appVersion = (string) $appVersion;
		$this->appVersion = $appVersion;
	}

	/**
	 * Getter for human-readable name
	 *
	 * @return	$appName	The application's human-readable name
	 */
	public final function getAppName () {
		return $this->appName;
	}

	/**
	 * Setter for human-readable name
	 *
	 * @param		$appName	The application's human-readable name
	 * @return	void
	 */
	public final function setAppName ($appName) {
		// Cast and set it
		$appName = (string) $appName;
		$this->appName = $appName;
	}

	/**
	 * Getter for short uni*-like name
	 *
	 * @return	$shortName	The application's short uni*-like name
	 */
	public final function getAppShortName () {
		return $this->shortName;
	}

	/**
	 * Setter for short uni*-like name
	 *
	 * @param		$shortName	The application's short uni*-like name
	 * @return	void
	 */
	public final function setAppShortName ($shortName) {
		// Cast and set it
		$shortName = (string) $shortName;
		$this->shortName = $shortName;
	}

	/**
	 * Launcher for the application selector
	 *
	 * @return	void
	 * @see		ApplicationSelector
	 */
	public final function entryPoint () {
		// Get a prepared instance of ApplicationSelector
		$selInstance = ApplicationSelector::createApplicationSelector(LanguageSystem::getInstance(), FileIOHandler::getInstance());

		// Remove the ignore list from the object
		$selInstance->removeDirIgnoreList();

		// Next load all templates for the respective short app names
		$selInstance->loadApplicationTemplates();

		// Then load the selector's own template
		$selInstance->loadSelectorTemplate();

		// Insert all application templates
		$selInstance->insertApplicationTemplates();
	}
}

// [EOF]
?>
